from setuptools import setup, find_packages
from pathlib import Path



setup(
    name='neuronum',
    version='1.0.1',
    author='Neuronum Cybernetics',
    author_email='welcome@neuronum.net',
    description='Interact with the Neuronum Network to build, connect & automate economic data streams',
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'requests',  
    ],
    python_requires='>=3.6', 
)
